@@ -1,4 +1,4 @@
-/*
+#/*
  *  IMS Open Corpus Workbench (CWB)
  *  Copyright (C) 1993-2006 by IMS, University of Stuttgart
  *  Copyright (C) 2007-     by the respective contributers (see file AUTHORS)
@@ -131,7 +131,7 @@ typedef union c_tree {
     enum bnodetype type;                  /**< must be pa_ref */
     LabelEntry     label;                 /**< may be empty (NULL) */
     Attribute     *attr;                  /**< the P-attribute we are referring to */
-    int            delete;                /**< delete label after using it ? */
+    int            del;                /**< delete label after using it ? */
   }                pa_ref;
 
   /**
@@ -150,7 +150,7 @@ typedef union c_tree {
     enum bnodetype type;                  /**< must be sa_ref */
     LabelEntry     label;                 /**< may be empty (NULL) */
     Attribute     *attr;                  /**< the s-attribute we are referring to */
-    int            delete;                /**< delete label after using it ? */
+    int            del;                /**< delete label after using it ? */
   }                sa_ref;
 
   struct {
@@ -165,7 +165,7 @@ typedef union c_tree {
     int            negated;
     int            nr_items;
     int           *items;                 /**< an array of item IDs of size nr_items */
-    int            delete;                /**< delete label after using it ? */
+    int            del;                /**< delete label after using it ? */
   }                idlist;
 
   /** constant (string, int, float, ...) */
@@ -371,7 +371,7 @@ typedef struct ctxtsp {
  * eep contains the index of the highest currently-occupied slot within Environment.
  * @see Environment
  */
-int eep;
+extern int eep;
 
 /**
  * The EvalEnvironment object: environment variables for the evaluation of
@@ -417,9 +417,10 @@ typedef struct evalenv {
 typedef EvalEnvironment *EEP;
 
 /** A global array of EvalEnvironment structures */
-EvalEnvironment Environment[MAXENVIRONMENT];
 
-EEP CurEnv, evalenv;
+extern EvalEnvironment Environment[MAXENVIRONMENT];
+
+extern EEP CurEnv, evalenv;
 
 /* ---------------------------------------------------------------------- */
 
