@@ -8,7 +8,7 @@ test_that(
     M <- region_matrix_to_count_matrix(
       corpus = "REUTERS",
       p_attribute = "word",
-      registry = system.file(package = "RcppCWB", "extdata", "cwb", "registry"),
+      registry = use_tmp_registry(),
       matrix = matrix(c(0, 91), nrow = 1)
     )
     expect_equal(M[16,2], 5L)
